## 1.7.0 (2022-06-06)

### Feat

- add partial AsyncIOMotorClient

## 1.6.0 (2022-06-06)

### Feat

- add partial AsyncIOMotorClient

## 1.5.0 (2022-06-06)

### Feat

- add partial AsyncIOMotorClient

## 1.4.0 (2022-06-04)

### Feat

- update project README

## 1.3.0 (2022-06-04)

### Feat

- pyproject description

## 1.2.2 (2022-06-04)

### Fix

- make typevar more specific

## 1.2.1 (2022-06-04)

### Fix

- AgnosticCursor ChainingMethod

## 1.2.0 (2022-06-04)

### Feat

- AgnosticCursor pyi

## 1.1.1 (2022-06-04)

### Fix

- add async to find

## 1.1.0 (2022-06-04)

### Feat

- replace pymongo Cursor to AgnosticCursor

## 1.0.1 (2022-06-04)

### Fix

- replace pymongo Cursor to AgnosticCursor

## 1.0.0 (2022-06-04)

### BREAKING CHANGE

- rename package

## 0.6.0 (2022-06-04)

### Feat

- AsyncIOMotorCollection pyi

## 0.5.0 (2022-06-03)

### Feat

- update pyi

## 0.4.1 (2022-06-03)

### Fix

- missing database pyi

## 0.4.0 (2022-06-03)

### Feat

- database pyi

## 0.3.1 (2022-06-03)

### Fix

- put the file to correct place

## 0.3.0 (2022-06-03)

### Feat

- create_asyncio_class stub

## 0.2.2 (2022-06-03)

### Fix

- poetry build

## 0.2.1 (2022-06-03)

### Fix

- __init__.py to __init__.pyi

## 0.2.0 (2022-06-03)

### Feat

- motor collection stub

## 0.1.0 (2022-06-03)
